@@ -3,9 +3,15 @@
 
 #' @importFrom xtable xtable
 #' @importFrom graphics plot
+#' @importFrom rlang .data
 #' @import stats
 NULL
 
+## CRAN Note avoidance.
+if (getRversion() >= "2.15.1") {
+  utils::globalVariables("count")
+}
+
 statgenDefaultOptions <- list(
   ##palette.colors(palette = "Dark 2")
   statgen.genoColors = c("#1B9E77", "#D95F02", "#7570B3", "#E7298A", "#66A61E",
