@@ -7,9 +7,10 @@ if (requireNamespace("asreml", quietly = TRUE)) {
     test_that(paste(deparse(substitute(STA)), "has correct STA structure"), {
       expect_is(STA, "STA")
       for (tr in names(STA)) {
-        expect_length(STA[[tr]], 9)
+        expect_length(STA[[tr]], 10)
         expect_named(STA[[tr]], c("mRand", "mFix", "TD", "traits", "design",
-                                  "spatial", "engine", "predicted", "sumTab"))
+                                  "spatial", "engine", "predicted", "sumTab",
+                                  "useCheckId"))
         expect_is(STA[[tr]]$TD, "TD")
       }
     })
@@ -95,7 +96,7 @@ if (requireNamespace("asreml", quietly = TRUE)) {
     expect_is(modelAsTs[["E1"]]$spatial, "list")
     expect_length(modelAsTs[["E1"]]$spatial, 1)
     expect_named(modelAsTs[["E1"]]$spatial, "t1")
-    expect_equal(modelAsTs[["E1"]]$spatial$t1, "AR1(x)AR1 - units")
+    expect_equal(modelAsTs[["E1"]]$spatial$t1, "AR1(x)id ")
   })
 
   test_that("option spatial functions properly with missing data", {
@@ -119,7 +120,7 @@ if (requireNamespace("asreml", quietly = TRUE)) {
     expect_warning(modelAsTs <- fitTD(testTD, design = "ibd", traits = "t1",
                                       spatial = TRUE, engine = "asreml",
                                       control = list(criterion = "BIC")))
-    expect_equal(modelAsTs[["E1"]]$spatial$t1, "AR1(x)AR1 - units")
+    expect_equal(modelAsTs[["E1"]]$spatial$t1, "AR1(x)id ")
   })
 
   ### Missing data.
